.. role:: draft
.. role:: ready
.. role:: closed

********************
Administration panel
********************

Chat manage
===========

Page with list of chats. Such table does not contain message information and looks like:

.. list-table::
  
    * - Chat token
      - Created
      - Status

    * - 5******2708
      - 10-May-2015, 18:29:48
      - :ready:`ready`

    * - 5******d8c8
      - 18-Apr-2015, 10:01:11
      - :draft:`draft`

    * - 5******d8c7
      - 18-Apr-2015, 09:01:11
      - :closed:`closed`

Clear chat
==========

Link that runs manually clear chat cron.
